from django.db.models.fields import FloatField


class OrdinalField(FloatField):

    def __init__(self, *args, **kwargs):
        kwargs['null'] = kwargs.get('null', False)
        kwargs['default'] = kwargs.get('default', 0)
        super(OrdinalField, self).__init__(*args, **kwargs)


from django.db import models


class DateTimeModelMixin(models.Model):
    created_at = models.DateTimeField(auto_now_add=True, verbose_name='Created')
    updated_at = models.DateTimeField(auto_now=True, verbose_name='Updated')

    class Meta:
        abstract = True



from django.contrib import admin


class NotDeletableAdmin(admin.ModelAdmin):

    def get_actions(self, request):
        actions = super(NotDeletableAdmin, self).get_actions(request)
        del actions['delete_selected']
        return actions

    def has_delete_permission(self, request, obj=None):
        return False
